translate.convert.prop2po

Package translate :: Package convert :: Module prop2po |
[hide private]
[frames] | no frames]

# Module prop2po

source code

convert Java/Mozilla .properties files to Gettext PO localization files

See: http://translate.sourceforge.net/wiki/toolkit/prop2po for examples and usage instructions

Classes | [hide private]
| prop2po convert a .properties file to a .po file for handling the translation...

Functions | [hide private]
convertmozillaprop(inputfile, outputfile, templatefile, pot=False, duplicatestyle="msgctxt") Mozilla specific convertor function | source code
convertprop(inputfile, outputfile, templatefile, personality="java", pot=False, duplicatestyle="msgctxt") reads in inputfile using properties, converts using prop2po, writes to outputfile | source code
main(argv=None) | source code

Imports: sys, po, properties